==> kit-vue-1.16.12.tgz: package/src/index.js <==
import { ShCard, ShCardHeader, ShCardBox, ShCardWidget, ShCardGroup } from './components/sh-card';
import ShNotifications from './components/sh-notifications';
import { ShButton, ShButtonGroup } from './components/sh-button';
import ShButtonUpload from './components/sh-button-upload';
import { ShCheckbox, ShCheckboxGroup } from './components/sh-checkbox';
import { ShRadio, ShRadioGroup } from './components/sh-radio';
import { ShStatistics, ShStatisticsItem } from './components/sh-statistics';
import ShInput from './components/sh-input';
import ModalProgrammatic, { ShModal } from './components/sh-modal';
import ShDialog from './components/sh-dialog';
import ShImage from './components/sh-image';
import { ShTable, ShTableColumn } from './components/sh-table';
import { ShTag, ShTagButton, ShTagCreator } from './components/sh-tag';
import { ShField, ShFieldGroup } from './components/sh-field';
import ShIcon from './components/sh-icon';
import ShTextarea from './components/sh-textarea';
import ShSwitch from './components/sh-switch';
import ShPageHeader from './components/sh-page-header';
import ShDragableTags from './components/sh-dragable-tags';
import { ShDropdown, ShDropdownItem } from './components/sh-dropdown';
import ShNotificationBanner from './components/sh-notification-banner';
import ShBlankslate from './components/sh-blankslate';
import ShActionBarLayout from './components/sh-action-bar-layout';
import ShActionPage from './components/sh-action-page';
import ShLoading from './components/sh-loading';
import ShPhotosGrid from './components/sh-photos-grid';
import {ShHistory, ShComment, ShCustomerData} from './components/sh-history';
import ShSingleColumnLayout from './layouts/single-column';
import ShTwoColumnsLayout from './layouts/two-columns';
import ShReadMore from './directives/sh-read-more/sh-read-more';
import { ShAddress, ShData } from './components/sh-address';

const components = {
  ShData,
  ShAddress,
  ShDragableTags,
  ShCard,
  ShCardBox,
  ShHistory,
  ShComment,
  ShCustomerData,
  ShCardHeader,
  ShCardWidget,
  ShCardGroup,
  ShButton,
  ShButtonGroup,
  ShButtonUpload,
  ShTwoColumnsLayout,
  ShSingleColumnLayout,
  ShNotifications,
  ShCheckbox,
  ShCheckboxGroup,
  ShRadio,
  ShRadioGroup,
  ShInput,
  ShModal,
  ShTable,
  ShTableColumn,
  ShTag,
  ShTagCreator,
  ShField,
  ShFieldGroup,
  ShTagButton,
  ShIcon,
  ShSwitch,
  ShImage,
  ShTextarea,
  ShDropdown,
  ShDropdownItem,
  ShPageHeader,
  ShNotificationBanner,
  ShBlankslate,
  ShActionBarLayout,
  ShActionPage,
  ShPhotosGrid,
  ShStatistics,
  ShStatisticsItem,
};

const directives = {
  'read-more': ShReadMore
}

// const directives = {
//   ShInputCommit
// };

import en from './locale/en_US.json';
import pl from './locale/pl_PL.json';

components.install = (Vue, opts = {}) => {
  if (opts.i18n) {
    opts.i18n.mergeLocaleMessage('en', en);
    opts.i18n.mergeLocaleMessage('pl', pl);
  }
  Object.keys(components).forEach((name) =>{
    // @ts-ignore
    Vue.component(name, components[name]);
  });
  Object.keys(directives).forEach((name) => {
    Vue.directive(name, directives[name])
  });

// Object.keys(directives).forEach((name) =>{
//   // @ts-ignore
//   Vue.directive(name, directives[name]);
// });
  Vue.use(ShLoading.loading);
  Vue.prototype.$shdialog = ShDialog;
  Vue.prototype.$shmodal = ModalProgrammatic;
};

export {
  ShDialog,
  ModalProgrammatic
}

export default components;

==> kit-vue-2.3.8.tgz: package/src/index.js <==
import { ShCard, ShCardHeader, ShCardBox, ShCardWidget, ShCardGroup, ShCardWithTabs } from './components/sh-card';
import ShNotifications from './components/sh-notifications';
import { ShButton, ShButtonGroup } from './components/sh-button';
import ShLink from './components/sh-link';
import ShButtonUpload from './components/sh-button-upload';
import ShBannerTabs from './components/sh-banner-tabs';
import { ShCheckbox, ShCheckboxGroup } from './components/sh-checkbox';
import { ShRadio, ShRadioGroup } from './components/sh-radio';
import { ShStatistics, ShStatisticsItem } from './components/sh-statistics';
import ShInput from './components/sh-input';
import ModalProgrammatic, { ShModal } from './components/sh-modal';
import ShDialog from './components/sh-dialog';
import ShImage from './components/sh-image';
import { ShTable, ShTableColumn } from './components/sh-table';
import { ShTableCellActions } from './components/sh-table-cell';
import { ShTag, ShTagButton, ShTagCreator, ShTagIcon } from './components/sh-tag';
import { ShField, ShFieldGroup } from './components/sh-field';
import ShIcon from './components/sh-icon';
import ShTextarea from './components/sh-textarea';
import ShSwitch from './components/sh-switch';
import ShPageHeader from './components/sh-page-header';
import ShDragableTags from './components/sh-dragable-tags';
import { ShDropdown, ShDropdownItem } from './components/sh-dropdown';
import ShNotificationBanner from './components/sh-notification-banner';
import ShBlankslate from './components/sh-blankslate';
import ShActionBarLayout from './components/sh-action-bar-layout';
import ShActionPage from './components/sh-action-page';
import ShLoading from './components/sh-loading';
import ShPhotosGrid from './components/sh-photos-grid';
import { ShHistory, ShComment, ShCustomerData } from './components/sh-history';
import ShSingleColumnLayout from './layouts/single-column';
import ShTwoColumnsLayout from './layouts/two-columns';
import ShReadMore from './directives/sh-read-more/sh-read-more';
import ShRedactor from './components/sh-redactor';
import ShChannelTabs from './components/sh-channel-tabs';
import { ShAddress, ShData } from './components/sh-address';
import ShImageSelector from './components/sh-image-selector';
import ShUploadField from './components/sh-upload-field';
import ShLabel from './components/sh-label';
import ShProductCard from './components/sh-product-card';
import ShAutocompleter from './components/sh-autocompleter';
import ShPaginationList from './components/sh-pagination-list';
import ShCategoriesSelect from './components/sh-categories-select';
import ShProductPrice from './components/sh-product-price';
import ShColorpicker from './components/sh-colorpicker';
import ShTabs from './components/sh-tabs';
import ShCollectionPointsMap from './components/sh-collection-points';
import ShWrapper from './components/sh-wrapper';

const components = {
  ShData,
  ShAddress,
  ShTabs,
  ShDragableTags,
  ShHistory,
  ShComment,
  ShCustomerData,
  ShCard,
  ShCardBox,
  ShCardHeader,
  ShCardWidget,
  ShCardGroup,
  ShCardWithTabs,
  ShButton,
  ShButtonGroup,
  ShButtonUpload,
  ShLink,
  ShUploadField,
  ShTwoColumnsLayout,
  ShSingleColumnLayout,
  ShNotifications,
  ShCheckbox,
  ShCheckboxGroup,
  ShRadio,
  ShRadioGroup,
  ShInput,
  ShModal,
  ShTable,
  ShTableColumn,
  ShTableCellActions,
  ShTag,
  ShTagIcon,
  ShTagCreator,
  ShField,
  ShFieldGroup,
  ShTagButton,
  ShIcon,
  ShSwitch,
  ShImage,
  ShTextarea,
  ShDropdown,
  ShDropdownItem,
  ShPageHeader,
  ShNotificationBanner,
  ShBlankslate,
  ShActionBarLayout,
  ShActionPage,
  ShPhotosGrid,
  ShStatistics,
  ShStatisticsItem,
  ShBannerTabs,
  ShRedactor,
  ShChannelTabs,
  ShImageSelector,
  ShLabel,
  ShProductCard,
  ShAutocompleter,
  ShPaginationList,
  ShCategoriesSelect,
  ShProductPrice,
  ShColorpicker,
  ShCollectionPointsMap,
  ShWrapper
};

const directives = {
  'read-more': ShReadMore
};

import en from './locale/en_US.json';
import pl from './locale/pl_PL.json';

export default function install(Vue, opts = {}) {
  if (opts.i18n) {
    opts.i18n.mergeLocaleMessage('en', en);
    opts.i18n.mergeLocaleMessage('pl', pl);
  }
  Object.keys(components).forEach(name => {
    // @ts-ignore
    Vue.component(name, components[name]);
  });
  Object.keys(directives).forEach(name => {
    Vue.directive(name, directives[name]);
  });

  Vue.use(ShLoading.loading);
  Vue.prototype.$shdialog = ShDialog;
  Vue.prototype.$shmodal = ModalProgrammatic;
}
export {
  ShDialog,
  ModalProgrammatic,
  ShData,
  ShAddress,
  ShDragableTags,
  ShCard,
  ShCardBox,
  ShHistory,
  ShComment,
  ShCustomerData,
  ShCardHeader,
  ShCardWidget,
  ShCardGroup,
  ShCardWithTabs,
  ShButton,
  ShButtonGroup,
  ShButtonUpload,
  ShUploadField,
  ShTwoColumnsLayout,
  ShSingleColumnLayout,
  ShNotifications,
  ShCheckbox,
  ShCheckboxGroup,
  ShRadio,
  ShRadioGroup,
  ShInput,
  ShModal,
  ShTable,
  ShTableColumn,
  ShTableCellActions,
  ShTag,
  ShTagIcon,
  ShTagCreator,
  ShField,
  ShFieldGroup,
  ShTagButton,
  ShIcon,
  ShSwitch,
  ShImage,
  ShTextarea,
  ShDropdown,
  ShDropdownItem,
  ShPageHeader,
  ShNotificationBanner,
  ShBlankslate,
  ShActionBarLayout,
  ShActionPage,
  ShPhotosGrid,
  ShStatistics,
  ShStatisticsItem,
  ShBannerTabs,
  ShRedactor,
  ShChannelTabs,
  ShImageSelector,
  ShLabel,
  ShProductCard,
  ShAutocompleter,
  ShPaginationList,
  ShCategoriesSelect,
  ShProductPrice,
  ShColorpicker,
  ShWrapper
};

// export default components;
